import { StorageSQLite } from '../../app/storage/sqlite'
import { assert } from 'chai'
import { ItemData, ItemEntity, ItemsRepo } from './helper'

describe('ItemsRepoSQLite', () => {
    const dsn = __dirname + `/sqlite.test.db`
    let storage: StorageSQLite
    let repo: ItemsRepo

    beforeAll(async () => {
        storage = new StorageSQLite({ dsn })
        await storage.connect()
        storage.db.on('trace', (data: string) => {
            console.log(data)
        })
        repo = new ItemsRepo(storage)
        await repo.Recreate()
        for (const uid of ['foo', 'bar', 'pew', 'baz', 'fox']) {
            const d = new ItemData()
            d.uid = uid
            const e = new ItemEntity(d)
            await repo.save(e)
        }
    })

    describe('#findById', () => {
        it('should return persisted entity', async () => {
            const e = await repo.findById('foo')
            assert.isTrue(e.isPersisted())
            assert.isDefined(e._id)
        })
    })
})
